@@ -233,7 +233,7 @@ class GNEB_Node(NodeMixin):
             moving_endpoints         = bool(self.moving_endpoints),
             delta_Rx_left            = float(self.delta_Rx_left),
             delta_Rx_right           = float(self.delta_Rx_right),
-            image_types              = self.image_types,
+            image_types              = [ [int(t[0]), int(t[1]) ] for t in self.image_types],
             solver_llg               = int(self.solver_llg),
             solver_gneb              = int(self.solver_gneb)
         )
@@ -453,7 +453,7 @@ class GNEB_Node(NodeMixin):
                 self.noi = chain.get_noi(p_state)
 
             self.log("Number of images = {}".format(self.noi))
-            io.chain_write(p_state, self.chain_file)
+            self.save_chain(p_state)
 
     def _prepare_state(self, p_state):
         """Prepares the state and reads in the chain."""
@@ -486,6 +486,7 @@ class GNEB_Node(NodeMixin):
 
         # Set image types
         for idx_image, image_type in self.image_types:
+            self.log("Set type of image {} to {}".format(idx_image, image_type))
             parameters.gneb.set_climbing_falling(p_state, image_type, idx_image)
 
     def check_run_condition(self):
@@ -495,9 +496,22 @@ class GNEB_Node(NodeMixin):
         condition_convergence = not self._converged
 
         if self.allow_split: # Only care about minima if splitting is allowed
-            return condition_minima and condition_iterations and condition_convergence
+            result = condition_minima and condition_iterations and condition_convergence
         else:
-            return condition_iterations and condition_convergence
+            result = condition_iterations and condition_convergence
+
+        if not result: # We are stopping and log the reason
+            reason = ""
+            if self.allow_split and not condition_minima:
+                reason = "Intermediate minima found"
+            elif not condition_iterations:
+                reason = "Max. Iterations reached"
+            elif not condition_convergence:
+                reason = "Converged"
+
+            self.log("Stop running. Reason: {}".format( reason ))
+
+        return result
 
     def run(self):
         """Run GNEB with checks after a certain number of iterations"""
@@ -564,10 +578,7 @@ class GNEB_Node(NodeMixin):
 
                 self.update_energy_path(p_state)
 
-                if self._converged:
-                    self.log("Converged!")
-                else:
-                    self.spawn_children(p_state)
+                self.spawn_children(p_state)
 
                 self.save_chain(p_state)
 
@@ -614,7 +625,7 @@ class GNEB_Node(NodeMixin):
                     chain.pop_back(p_state)
 
             self.update_energy_path(p_state)
-            io.chain_write(p_state, self.chain_file)
+            self.save_chain(p_state)
 
     def clamp_and_refine(self, convergence=None, max_total_iterations=None, idx_max_list=None, apply_ci=True, target_noi=5):
         """One step of clamp and refine algorithm"""
